set_bednets.RdThe model will distribute bed nets at timesteps to a random
sample of the entire human population. The sample size will be a proportion
of the human population taken from the corresponding coverages.
The sample can contain humans who already have bed nets.
All of the sample "use" their bed nets on the timestep after they are distributed. Incomplete usage is not part of this model.
If a human in the sample already has a bed net, their bed net will be replaced by a new one.
Using the gamman parameter:
Bed nets will be randomly removed each timestep with a rate of 1 - exp(-1/retention)
Alternatively, the logistic retention parameters can be used. Retention time is calculated using the logistic decay function:
l (time at which all nets fail) = half_life / sqrt(1 - k / (k - log(0.5))) T (simulated time for individual failure) = l * sqrt( a / (1 + a ) ), a = -log(U)/k
The structure for the bed net model is documented in the S.I. of 10.1038/s41467-018-07357-w
set_bednets(
parameters,
timesteps,
coverages,
dn0,
rn,
rnm,
gamman,
retention = NULL,
logistic_half_life = NULL,
logistic_k = NULL
)a list of parameters to modify
the timesteps at which to distribute bed nets
the proportion of the human population who receive bed nets
a matrix of death probabilities for each species over time. With nrows=length(timesteps), ncols=length(species)
a matrix of repelling probabilities for each species over time With nrows=length(timesteps), ncols=length(species)
a matrix of minimum repelling probabilities for each species over time With nrows=length(timesteps), ncols=length(species)
a vector of bednet insecticide half-lives for each distribution timestep
(optional) the average number of timesteps a net is kept for (modelled using a log uniform)
(optional) bednet retention half-life (modelled using logistic decay)
(optional) k parameter for retention modelled using logistic decay