set_equilibrium.RdThis will update the IBM parameters to match the equilibrium parameters and set up the initial human and mosquito population to achieve init_EIR
set_equilibrium(
parameters,
init_EIR,
eq_params = NULL,
EIR_population_input = "adult"
)model parameters to update
the desired initial EIR (infectious bites per adult person per year).
parameters from the malariaEquilibrium package, if null The default malariaEquilibrium parameters will be used (not applicable for P. vivax).
the population corresponding with the initial EIR units, where options are "adult" (default) or "total".